@@ -2,7 +2,8 @@
 # For license information see LICENSE or https://opensource.org/licenses/BSD-3-Clause
 
 # Basic type aliases for usefulness.
-from typing import List, TypeVar, Union
+from datetime import timedelta
+from typing import Final, List, TypeVar, Union
 
 import numpy.typing as npt
 from astropy.time import Time
@@ -12,3 +13,5 @@ T = TypeVar('T')
 ScalarOrNDArray = Union[T, npt.NDArray[T]]
 TimeScalarOrNDArray = Union[Time, npt.NDArray[float]]
 ListOrNDArray = Union[List[T], npt.NDArray[T]]
+
+ZeroTime: Final[timedelta] = timedelta()
